/*
 * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
 * Use is subject to license terms.
 */

/*
 * JDOFatalException.java
 *
 * Created on March 8, 2000, 8:32 AM
 */

package javax.jdo;

/** This class represents exceptions that are fatal; that is, the condition
 * that caused it cannot be bypassed even if the operation is retried.
 *
 * @author  Craig Russell
 * @version 0.9
 */
public class JDOFatalException extends JDOException {

  /**
   * Constructs a new <code>JDOFatalException</code> without a detail message.
   */
  public JDOFatalException() {
  }
  

  /**
   * Constructs a new <code>JDOFatalException</code> with the specified detail message.
   * @param msg the detail message.
   */
  public JDOFatalException(String msg) {
    super(msg);
  }

  /**
   * Constructs a new <code>JDOFatalException</code> with the specified detail
   * message and nested <code>Throwable</code>s.
   * @param msg the detail message.
   * @param nested the nested <code>Throwable[]</code>.
   */
  public JDOFatalException(String msg, Throwable[] nested) {
    super(msg, nested);
  }
  
  /**
   * Constructs a new <code>JDOFatalException</code> with the specified detail
   * message and nested <code>Throwable</code>s.
   * @param msg the detail message.
   * @param nested the nested <code>Throwable</code>.
   */
  public JDOFatalException(String msg, Throwable nested) {
    super(msg, nested);
  }
  
  /** Constructs a new <code>JDOFatalException</code> with the specified detail message
   * and failed object.
   * @param msg the detail message.
   * @param failed the failed object.
   */
  public JDOFatalException(String msg, Object failed) {
    super(msg, failed);
  }
  
  /** Constructs a new <code>JDOFatalException</code> with the specified detail message,
   * nested <code>Throwable</code>s, and failed object.
   * @param msg the detail message.
   * @param nested the nested <code>Throwable[]</code>.
   * @param failed the failed object.
   */
  public JDOFatalException(String msg, Throwable[] nested, Object failed) {
    super(msg, nested, failed);
    
  }
  /** Constructs a new <code>JDOFatalException</code> with the specified detail message,
   * nested <code>Throwable</code>s, and failed object.
   * @param msg the detail message.
   * @param nested the nested <code>Throwable</code>.
   * @param failed the failed object.
   */
  public JDOFatalException(String msg, Throwable nested, Object failed) {
    super(msg, nested, failed);
  }
}

