/*
 * Copyright 2003 Sun Microsystems, Inc. All rights reserved.
 * Use is subject to license terms.
 */

/*
 * JDOOptimisticVerificationException.java
 *
 * Created on April 11, 2003
 */

package javax.jdo;

/** This class represents optimistic verification failures.  The nested
 * exception array contains an exception for each instance that failed
 * the optimistic verification.
 *
 * @author  Craig Russell
 * @version 1.0.1
 */
public class JDOOptimisticVerificationException extends JDOFatalDataStoreException {

  /**
   * Constructs a new <code>JDOOptimisticVerificationException</code> without a detail message.
   */
  public JDOOptimisticVerificationException() {
  }
  

  /**
   * Constructs a new <code>JDOOptimisticVerificationException</code> with the specified detail message.
   * @param msg the detail message.
   */
  public JDOOptimisticVerificationException(String msg) {
    super(msg);
  }

  /** Constructs a new <code>JDOOptimisticVerificationException</code> with the specified detail message
   * and failed object.
   * @param msg the detail message.
   * @param failed the failed object.
   */
  public JDOOptimisticVerificationException(String msg, Object failed) {
    super(msg, failed);
  }
  
  /**
   * Constructs a new <code>JDOOptimisticVerificationException</code> with the specified
   * detail message and nested <code>Throwable</code>s.
   * @param msg the detail message.
   * @param nested the nested <code>Throwable[]</code>.
   */
  public JDOOptimisticVerificationException(String msg, Throwable[] nested) {
    super(msg, nested);
  }

}

